==> zio-aws-networkmanager_2.13-5.17.150.1-sources.jar: zio/aws/networkmanager/model/CreateSiteToSiteVpnAttachmentResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateSiteToSiteVpnAttachmentResponse(
    siteToSiteVpnAttachment: Option[
      zio.aws.networkmanager.model.SiteToSiteVpnAttachment
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse = {
    import CreateSiteToSiteVpnAttachmentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse
      .builder()
      .optionallyWith(
        siteToSiteVpnAttachment.map(value => value.buildAwsValue())
      )(_.siteToSiteVpnAttachment)
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse.ReadOnly =
    zio.aws.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse
      .wrap(buildAwsValue())
}
object CreateSiteToSiteVpnAttachmentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse =
      zio.aws.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse(
        siteToSiteVpnAttachment.map(value => value.asEditable)
      )
    def siteToSiteVpnAttachment
        : Option[zio.aws.networkmanager.model.SiteToSiteVpnAttachment.ReadOnly]
    def getSiteToSiteVpnAttachment: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.SiteToSiteVpnAttachment.ReadOnly
    ] = AwsError.unwrapOptionField(
      "siteToSiteVpnAttachment",
      siteToSiteVpnAttachment
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse
  ) extends zio.aws.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse.ReadOnly {
    override val siteToSiteVpnAttachment: Option[
      zio.aws.networkmanager.model.SiteToSiteVpnAttachment.ReadOnly
    ] = scala
      .Option(impl.siteToSiteVpnAttachment())
      .map(value =>
        zio.aws.networkmanager.model.SiteToSiteVpnAttachment.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse
  ): zio.aws.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-networkmanager_2.13-6.20.58.1-sources.jar: zio/aws/networkmanager/model/CreateSiteToSiteVpnAttachmentResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateSiteToSiteVpnAttachmentResponse(
    siteToSiteVpnAttachment: Optional[
      zio.aws.networkmanager.model.SiteToSiteVpnAttachment
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse = {
    import CreateSiteToSiteVpnAttachmentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse
      .builder()
      .optionallyWith(
        siteToSiteVpnAttachment.map(value => value.buildAwsValue())
      )(_.siteToSiteVpnAttachment)
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse.ReadOnly =
    zio.aws.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse
      .wrap(buildAwsValue())
}
object CreateSiteToSiteVpnAttachmentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse =
      zio.aws.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse(
        siteToSiteVpnAttachment.map(value => value.asEditable)
      )
    def siteToSiteVpnAttachment: Optional[
      zio.aws.networkmanager.model.SiteToSiteVpnAttachment.ReadOnly
    ]
    def getSiteToSiteVpnAttachment: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.SiteToSiteVpnAttachment.ReadOnly
    ] = AwsError.unwrapOptionField(
      "siteToSiteVpnAttachment",
      siteToSiteVpnAttachment
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse
  ) extends zio.aws.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse.ReadOnly {
    override val siteToSiteVpnAttachment: Optional[
      zio.aws.networkmanager.model.SiteToSiteVpnAttachment.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.siteToSiteVpnAttachment())
      .map(value =>
        zio.aws.networkmanager.model.SiteToSiteVpnAttachment.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse
  ): zio.aws.networkmanager.model.CreateSiteToSiteVpnAttachmentResponse.ReadOnly =
    new Wrapper(impl)
}
